@@ -1,5 +1,7 @@
-package # Hide from the indexer.
-    MooseX::SingleArg::Meta::Class;
+package MooseX::SingleArg::Meta::Class;
+
+$MooseX::SingleArg::Meta::Class::VERSION = '0.09';
+
 use Moose::Role;
 
 has single_arg => (
